@@ -124,7 +124,9 @@ class AsrClient(AbstractClient):
 
 
     def CreateCustomization(self, request):
-        """用户使用该接口可以创建自学习模型，以供识别调用
+        """用户使用该接口可以创建自学习模型，以供识别调用。
+
+        注意：调用该接口后，模型会自动训练。新建模型成功后，调用ModifyCustomizationState接口修改为上线状态，即可在识别请求中使用对应模型ID。
 
         :param request: Request instance for CreateCustomization.
         :type request: :class:`tencentcloud.asr.v20190614.models.CreateCustomizationRequest`
