@@ -349,6 +349,8 @@ class CreateRecTaskRequest(AbstractModel):
 • 16k_en_edu 英文教育；
 • 16k_zh_medical  医疗；
 • 16k_th 泰语；
+• 16k_zh-PY 中英粤;
+• 16k_zh_dialect：多方言，支持23种方言（上海话、四川话、武汉话、贵阳话、昆明话、西安话、郑州话、太原话、兰州话、银川话、西宁话、南京话、合肥话、南昌话、长沙话、苏州话、杭州话、济南话、天津话、石家庄话、黑龙江话、吉林话、辽宁话）；
         :type EngineModelType: str
         :param ChannelNum: 识别声道数。1：单声道（非电话场景，直接选择单声道即可，忽略音频声道数）；2：双声道（仅支持8k_zh电话场景，双声道应分别对应通话双方）。注意：双声道的电话音频已物理分离说话人，无需再开启说话人分离功能。
         :type ChannelNum: int
@@ -364,7 +366,7 @@ class CreateRecTaskRequest(AbstractModel):
         :type SpeakerNumber: int
         :param CallbackUrl: 回调 URL，用户自行搭建的用于接收识别结果的服务URL。如果用户使用轮询方式获取识别结果，则无需提交该参数。回调格式&内容详见：[录音识别回调说明](https://cloud.tencent.com/document/product/1093/52632)
         :type CallbackUrl: str
-        :param Url: 语音的URL地址，需要公网可下载。长度小于2048字节，当 SourceType 值为 0 时须填写该字段，为 1 时不需要填写。注意：请确保录音文件时长在5个小时之内，否则可能识别失败。请保证文件的下载速度，否则可能下载失败。
+        :param Url: 语音的URL地址，需要公网环境浏览器可下载。当 SourceType 值为 0 时须填写该字段，为 1 时不需要填写。注意：请确保录音文件时长在5个小时之内，否则可能识别失败。请保证文件的下载速度，否则可能下载失败。
         :type Url: str
         :param Data: 语音数据base64编码，当SourceType 值为1时必须填写，为0可不写。音频数据要小于5MB。
         :type Data: str
@@ -384,6 +386,10 @@ class CreateRecTaskRequest(AbstractModel):
         :type FilterPunc: int
         :param FilterModal: 是否过滤语气词（目前支持中文普通话引擎）。0：不过滤语气词；1：部分过滤；2：严格过滤 。默认值为 0。
         :type FilterModal: int
+        :param EmotionalEnergy: 情绪能量值，取值为音量分贝值/10。取值范围：[1,10]。值越高情绪越强烈。0:不开启，1:开启
+        :type EmotionalEnergy: int
+        :param ReinforceHotword: 热词增强功能。1:开启后（仅支持8k_zh,16k_zh），将开启同音替换功能，同音字、词在热词中配置。举例：热词配置“蜜制”并开启增强功能后，与“蜜制”同拼音（mizhi）的“秘制”、“蜜汁”的识别结果会被强制替换成“蜜制”。因此建议客户根据自己的实际情况开启该功能。
+        :type ReinforceHotword: int
         """
         self.EngineModelType = None
         self.ChannelNum = None
@@ -402,6 +408,8 @@ class CreateRecTaskRequest(AbstractModel):
         self.Extra = None
         self.FilterPunc = None
         self.FilterModal = None
+        self.EmotionalEnergy = None
+        self.ReinforceHotword = None
 
 
     def _deserialize(self, params):
@@ -422,6 +430,8 @@ class CreateRecTaskRequest(AbstractModel):
         self.Extra = params.get("Extra")
         self.FilterPunc = params.get("FilterPunc")
         self.FilterModal = params.get("FilterModal")
+        self.EmotionalEnergy = params.get("EmotionalEnergy")
+        self.ReinforceHotword = params.get("ReinforceHotword")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1121,6 +1131,12 @@ class SentenceDetail(AbstractModel):
         :param SpeakerId: 声道或说话人 Id（请求中如果设置了 speaker_diarization或者ChannelNum为双声道，可区分说话人或声道）
 注意：此字段可能返回 null，表示取不到有效值。
         :type SpeakerId: int
+        :param EmotionalEnergy: 情绪能量值，取值为音量分贝值/10。取值范围：[1,10]。值越高情绪越强烈。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type EmotionalEnergy: float
+        :param SilenceTime: 本句与上一句之间的静音时长
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SilenceTime: int
         """
         self.FinalSentence = None
         self.SliceSentence = None
@@ -1130,6 +1146,8 @@ class SentenceDetail(AbstractModel):
         self.Words = None
         self.SpeechSpeed = None
         self.SpeakerId = None
+        self.EmotionalEnergy = None
+        self.SilenceTime = None
 
 
     def _deserialize(self, params):
@@ -1146,6 +1164,8 @@ class SentenceDetail(AbstractModel):
                 self.Words.append(obj)
         self.SpeechSpeed = params.get("SpeechSpeed")
         self.SpeakerId = params.get("SpeakerId")
+        self.EmotionalEnergy = params.get("EmotionalEnergy")
+        self.SilenceTime = params.get("SilenceTime")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1162,7 +1182,7 @@ class SentenceRecognitionRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param ProjectId: 腾讯云项目 ID，废弃参数，默认填写0即可。
+        :param ProjectId: 腾讯云项目 ID，废弃参数，填写0即可。
         :type ProjectId: int
         :param SubServiceType: 子服务类型。2： 一句话识别。
         :type SubServiceType: int
@@ -1176,14 +1196,16 @@ class SentenceRecognitionRequest(AbstractModel):
 • 16k_ca：16k 粤语；
 • 16k_ja：16k 日语；
 • 16k_zh_medical：16k 医疗；
+• 16k_zh-PY 中英粤;
+• 16k_zh_dialect：多方言，支持23种方言（上海话、四川话、武汉话、贵阳话、昆明话、西安话、郑州话、太原话、兰州话、银川话、西宁话、南京话、合肥话、南昌话、长沙话、苏州话、杭州话、济南话、天津话、石家庄话、黑龙江话、吉林话、辽宁话）；
         :type EngSerViceType: str
         :param SourceType: 语音数据来源。0：语音 URL；1：语音数据（post body）。
         :type SourceType: int
         :param VoiceFormat: 识别音频的音频格式，支持wav、pcm、ogg-opus、speex、silk、mp3、m4a、aac。
         :type VoiceFormat: str
-        :param UsrAudioKey: 用户端对此任务的唯一标识。废弃参数，忽略即可。
+        :param UsrAudioKey: 废弃参数，填写任意字符串即可。
         :type UsrAudioKey: str
-        :param Url: 语音 URL，公网可下载。当 SourceType 值为 0（语音 URL上传） 时须填写该字段，为 1 时不填；URL 的长度大于 0，小于 2048，需进行urlencode编码。音频时长不能超过60s，音频文件大小不能超过3MB。
+        :param Url: 语音的URL地址，需要公网环境浏览器可下载。当 SourceType 值为 0时须填写该字段，为 1 时不填。音频时长不能超过60s，音频文件大小不能超过3MB。
         :type Url: str
         :param Data: 语音数据，当SourceType 值为1（本地语音数据上传）时必须填写，当SourceType 值为0（语音 URL上传）可不写。要使用base64编码(采用python语言时注意读取文件应该为string而不是byte，以byte格式读取后要decode()。编码后的数据不可带有回车换行符)。音频时长不能超过60s，音频文件大小不能超过3MB（Base64后）。
         :type Data: str
@@ -1203,6 +1225,8 @@ class SentenceRecognitionRequest(AbstractModel):
         :type HotwordId: str
         :param CustomizationId: 自学习模型 id。如设置了该参数，将生效对应的自学习模型。
         :type CustomizationId: str
+        :param ReinforceHotword: 热词增强功能。1:开启后（仅支持8k_zh,16k_zh），将开启同音替换功能，同音字、词在热词中配置。举例：热词配置“蜜制”并开启增强功能后，与“蜜制”同拼音（mizhi）的“秘制”、“蜜汁”的识别结果会被强制替换成“蜜制”。因此建议客户根据自己的实际情况开启该功能。
+        :type ReinforceHotword: int
         """
         self.ProjectId = None
         self.SubServiceType = None
@@ -1220,6 +1244,7 @@ class SentenceRecognitionRequest(AbstractModel):
         self.ConvertNumMode = None
         self.HotwordId = None
         self.CustomizationId = None
+        self.ReinforceHotword = None
 
 
     def _deserialize(self, params):
@@ -1239,6 +1264,7 @@ class SentenceRecognitionRequest(AbstractModel):
         self.ConvertNumMode = params.get("ConvertNumMode")
         self.HotwordId = params.get("HotwordId")
         self.CustomizationId = params.get("CustomizationId")
+        self.ReinforceHotword = params.get("ReinforceHotword")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
